@@ -1,14 +1,14 @@
-def workspace(**kwargs):
+def workspaces(**kwargs):
     return "workspaces/{wid}".format(**kwargs)
 
 
-def configuration(**kwargs):
+def configurations(**kwargs):
     return "workspaces/{wid}/configurations/{cid}".format(**kwargs)
 
 
-def state(**kwargs):
+def states(**kwargs):
     return "workspaces/{wid}/configurations/{cid}/states/{sid}".format(**kwargs)
 
 
-def paramSet(**kwargs):
+def paramSets(**kwargs):
     return "workspaces/{wid}/configurations/{cid}/states/{sid}/paramSets/{psid}".format(**kwargs)
